Module bitmap

Module bitmap 

Bitmap implementation

The bitmap is a compact representation of a sequence of bits, using chunks of bytes for a more-efficient memory layout than doing Vec<bool>.

Modules

historical
A historical wrapper around crate::bitmap::Prunable that maintains snapshots via diffs.

Structs

BitMap
A bitmap that stores data in chunks of N bytes.
Iterator
Iterator over bits in a BitMap.
OnesIter
Iterator over the indices of set (1) bits in a bitmap.
Prunable
A prunable bitmap that stores data in chunks of N bytes.

Constants

DEFAULT_CHUNK_SIZE
The default BitMap chunk size in bytes.

Traits

Readable
Read-only access to a bitmap’s chunks and metadata.