N5f1

Struct N5f1 

pub struct N5f1;
Fault model requiring n >= 5f + 1 participants.

Tolerates up to f = (n-1)/5 faults with quorum size q = n - f (also provided as l_quorum).

Also provides m_quorum which computes 2f + 1.

Example

nfquorum (n-f)m-quorum (2f+1)
6153
11295
163137
214179

Implementations

Source

impl N5f1

pub fn m_quorum(n: impl ToPrimitive) -> u32

Compute 2f + 1.

Panics

Panics if n is zero, negative, or exceeds u32::MAX.

pub fn l_quorum(n: impl ToPrimitive) -> u32

Compute n - f.

This is equivalent to Self::quorum.

Panics

Panics if n is zero, negative, or exceeds u32::MAX.