Module futures

Module futures 

Utilities for working with futures.

Structs

AbortablePool
An unordered pool of futures that can be individually aborted.
Aborter
A handle that can be used to abort a specific future in an AbortablePool.
OptionFuture
An optional future that yields Poll::Pending when None. Useful within select! macros, where a future may be conditionally present.
Pool
An unordered pool of futures.

Traits

Threaded
A consuming mutation’s return value: the threaded value first, then any extra outputs.

Functions

rebind
Threads the value in slot through a consuming mutation, restoring the returned value and yielding the mutation’s extra outputs.
rebind_entry
Threads the value at key in map through a consuming mutation, restoring the returned value and yielding the mutation’s extra outputs.