Pool

Struct Pool 

pub struct Pool<'a, T> { /* private fields */ }
An unordered pool of futures.

Futures can be added to the pool, and removed from the pool as they resolve.

Note: This pool is not thread-safe and should not be used across threads without external synchronization.

Implementations

Source

impl<'a, T: Send> Pool<'a, T>

pub fn len(&self) -> usize

Returns the number of futures in the pool.

pub fn is_empty(&self) -> bool

Returns true if the pool is empty.

pub fn push(&mut self, future: impl Future<Output = T> + Send + 'a)

Adds a future to the pool.

The future must be Send and outlive 'a to ensure it can be safely stored and executed.

pub fn next_completed( &mut self, ) -> SelectNextSome<'_, FuturesUnordered<Pin<Box<dyn Future<Output = T> + Send + 'a>>>>

Returns a futures that resolves to the next future in the pool that resolves.

If the pool is empty, the future will never resolve.

pub fn cancel_all(&mut self)

Cancels all futures in the pool.

Excludes the dummy future.