Module iter

Module iter 

Iterator types with additional invariants.

Structs

NonEmpty
An iterator source guaranteed to yield at least one item.
ZipEq
See zip_eq.

Functions

zip_eq
Zips two iterators, panicking if one is exhausted before the other.