macro_rules! non_empty_range {
($start:expr, $end:expr) => { ... };
}Expand description
A macro to create a NonEmptyRange from a range expression, panicking if the range is empty.
macro_rules! non_empty_range {
($start:expr, $end:expr) => { ... };
}A macro to create a NonEmptyRange from a range expression, panicking if the range is empty.