Module sequence

Module sequence 

Re-exports

pub use fixed_bytes::FixedBytes;
pub use u64::U64;
pub use vec_u64::VecU64;
pub use u32::U32;
pub use unit::Unit;

Modules

fixed_bytes
prefixed_u64
A u64 array type with a prefix byte to allow for multiple key contexts.
u32
u64
unit
vec_u64
A u64 encoded with the same framing as a Vec<u8> of its big-endian bytes.

Enums

Error
Errors returned by the Array trait’s functions.

Traits

Array
Types that can be fallibly read from a fixed-size byte sequence.
Span
Types that can be read from a variable-size byte sequence.