pub struct TracedAsyncMutex<T> { /* private fields */ }Expand description
A Tokio-based async mutex whose acquisitions are recorded as tracing spans.
Each lock is identified by a static name, recorded as the lock field on the
utils.mutex.lock span so wait time is attributable to a specific lock.
Implementations
Sourceimpl<T> TracedAsyncMutex<T>
impl<T> TracedAsyncMutex<T>