Utilities for working with futures.
Structs
- Abortable
Pool - An unordered pool of futures that can be individually aborted.
- Aborter
- A handle that can be used to abort a specific future in an AbortablePool.
- Option
Future - An optional future that yields Poll::Pending when None. Useful within
select!macros, where a future may be conditionally present. - Pool
- An unordered pool of futures.
Traits
- Threaded
- A consuming mutation’s return value: the threaded value first, then any extra outputs.
Functions
- rebind
- Threads the value in
slotthrough a consuming mutation, restoring the returned value and yielding the mutation’s extra outputs. - rebind_
entry - Threads the value at
keyinmapthrough a consuming mutation, restoring the returned value and yielding the mutation’s extra outputs.