pub struct NonEmpty<I: Iterator> { /* private fields */ }Expand description
An iterator source guaranteed to yield at least one item.
Examples
use commonware_utils::iter::NonEmpty;
let items = NonEmpty::try_new([1, 2, 3].into_iter()).expect("items are non-empty");
assert_eq!(items.into_iter().collect::<Vec<_>>(), vec![1, 2, 3]);Implementations
Sourceimpl<I: Iterator> NonEmpty<I>
impl<I: Iterator> NonEmpty<I>
Sourcepub const fn new(first: I::Item, rest: I) -> Self
pub const fn new(first: I::Item, rest: I) -> Self
Creates a non-empty iterator from a first item and the remaining items.
Sourcepub fn try_new(items: I) -> Option<Self>
pub fn try_new(items: I) -> Option<Self>
Creates a non-empty iterator from items, or returns None when it is empty.
Sourcepub fn into_parts(self) -> (I::Item, I)
pub fn into_parts(self) -> (I::Item, I)
Consumes this source, returning its first item and remaining iterator.