pub struct UpgradableAsyncRwLock<T> { /* private fields */ }Expand description
A Tokio-based async rwlock with an upgradable read mode.
All write and upgradable_read acquisitions take an internal async mutex (“gate”) first.
This ensures that upgrading from read to write does not allow another writer to slip in.
Implementations
Sourceimpl<T> UpgradableAsyncRwLock<T>
impl<T> UpgradableAsyncRwLock<T>
Sourcepub async fn read(&self) -> RwLockReadGuard<'_, T>
pub async fn read(&self) -> RwLockReadGuard<'_, T>
Acquire a shared read guard.
Sourcepub async fn write(&self) -> UpgradableAsyncRwLockWriteGuard<'_, T>
pub async fn write(&self) -> UpgradableAsyncRwLockWriteGuard<'_, T>
Acquire an exclusive write guard.
Writers are serialized through the internal gate.
Sourcepub async fn upgradable_read(
&self,
) -> UpgradableAsyncRwLockUpgradableReadGuard<'_, T>
pub async fn upgradable_read( &self, ) -> UpgradableAsyncRwLockUpgradableReadGuard<'_, T>
Acquire an upgradable read guard.
This allows shared reads, then a later UpgradableAsyncRwLockUpgradableReadGuard::upgrade to exclusive write while holding the same gate token.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the lock and return the wrapped value.